@@ -58,7 +58,7 @@ use Math::Symbolic::Derivative qw//;
 
 use base 'Math::Symbolic::Base';
 
-our $VERSION = '0.131';
+our $VERSION = '0.132';
 
 =head1 CLASS DATA
 
@@ -911,7 +911,9 @@ operators).
 
 value() with named arguments (key/value pairs) associates variables in the tree
 with the value-arguments if the corresponging key matches the variable name.
-(Can one say this any more complicated?)
+(Can one say this any more complicated?) Since version 0.132, an
+equivalent and valid syntax is to pass a single hash reference instead of a
+list.
 
 Example: $tree->value(x => 1, y => 2, z => 3, t => 0) assigns the value 1 to
 any occurrances of variables of the name "x", aso.
